
/**
 * This class is a manual work around HPSF
 * <NOBR>DocumentSummaryInformation.getCategory()</NOBR> bug.
 * This method calls <NOBR>getProperty();</NOBR> which further calls
 * <NOBR>getSingleSection().getProperty();</NOBR>. Now, <NOBR>getSingleSection()</NOBR>
 * throws a <I>NoSingleSectionException</I> for <NOBR>Word 8.0/97-2000</NOBR> documents
 * because these have two sections and only one is expected. Here's the stack trace: <BR>
 * <PRE>
 * org.apache.poi.hpsf.NoSingleSectionException: Property set contains 2 sections.
 *     at org.apache.poi.hpsf.PropertySet.getSingleSection(PropertySet.java)
 *     at org.apache.poi.hpsf.SpecialPropertySet.getSingleSection(SpecialPropertySet.java)
 *     at org.apache.poi.hpsf.PropertySet.getProperty(PropertySet.java)
 *     at org.apache.poi.hpsf.DocumentSummaryInformation.getCategory(DocumentSummaryInformation.java)
 * </PRE>
 *
 * @author  Miroslav Obradovic
 * @e-mail  micky@eunet.yu
 * @date    21/11/2002
 * @version 1.0
 */
public class MyDocumentSummaryInformation
        extends org.apache.poi.hpsf.DocumentSummaryInformation {
    
    /**
     * Creates a DocumentSummaryInformation from a given PropertySet.
     */
    public MyDocumentSummaryInformation(final org.apache.poi.hpsf.PropertySet ps) 
            throws org.apache.poi.hpsf.UnexpectedPropertySetTypeException {
        
         super(ps);
    }
    
    /**
     * Returns the stream's category (or <code>null</code>).
     */
    public String getCategory() {
        
        int pid = org.apache.poi.hpsf.wellknown.PropertyIDMap.PID_CATEGORY;  // equals 2
        String category = null;
        
        java.util.List sections = getSections();
        int sectionCount = (int) getSectionCount();
        org.apache.poi.hpsf.Section section = null;
        org.apache.poi.hpsf.Property[] properties = null;
        
        // Iterate through sections, get their properties and look for Category.
        // Category should be found in the section with index 0.
        for (int i = 0; i < sectionCount; i++) {
            
            try {
                
                // Get the current section.
                section = (org.apache.poi.hpsf.Section) sections.get(i);
                
                // Get section properties and look for Category.
                properties = section.getProperties();
                for (int j = 0; j < properties.length; j++) {
                    
                    if (properties[j].getID() == pid) {
                        
                        category = (String) properties[j].getValue();
                        break;
                    }
                }
                
                // If Category found, break the loop.
                if (category != null) {
                    
                    break;
                }
                
            } catch (Exception e) {
                
                category = null;
            }
        }
        
        return category;
    }
}
